@@ -63,13 +63,11 @@ def conv2d(input: Union["Tensor", xp.ndarray], filters: Union["Tensor", xp.ndarr
     if not depthwise:
         slides = slider(input)  # (N, C, out_H, out_W, F_H, F_W)
         filters = filters # (F_N, C, F_H, F_W)
-        # Use opt_einsum for standard convolutions (benchmark winner)
         output = ng.einsum("ncpqhw,fchw->nfpq", slides, filters, backend="opt_einsum") # (N, F_N, out_H, out_W) 
     else:
         slides = slider(input)  # (N, C, out_H, out_W, F_H, F_W)
         filters = filters # (C, F_H, F_W)
-        # Use native xp einsum for depthwise convolutions (benchmark winner)
-        output = ng.einsum('ncpqhw,chw->ncpq', slides, filters, backend="xp") # (N, C, out_H, out_W)
+        output = ng.einsum('ncpqhw,chw->ncpq', slides, filters, backend="opt_einsum") # (N, C, out_H, out_W)
     return output
 
 
